@@ -1,6 +1,6 @@
 import argparse
 import os
-
+import json
 from click import UsageError
 
 import deepdriver
@@ -120,12 +120,11 @@ def init(config, exp_name, team_name):
     cli_func.api_login(config)
 
     run = deepdriver.init(exp_name=exp_name, team_name=team_name)
-
-    cli_func.run_dump(path_dir=config.config_base_dir, run=run)
+    cli_func.save_run_dump(path_dir=config.config_base_dir, run=run)
 
 
 @click.command('artifact', short_help='Upload or Download the Deepdriver Artifact')
-@click.argument('command', type=click.Choice(['upload', 'download'], case_sensitive=False))
+@click.argument('command', type=click.Choice(['upload', 'download'], case_sensitive=False), required=True)
 @click.option('--type', help='Type of artifact', prompt="Select type f Artifact",
               type=click.Choice(['model', 'dataset', 'code']), required=True)
 @click.option('--name', help='Name of artifact', prompt="Input the name of Artifact", required=True)
@@ -137,8 +136,7 @@ def artifact(config, command, type, name, tag, path):
         cli_func.api_setting(config)
         cli_func.api_login(config)
 
-        run = cli_func.run_load(path_dir=config.config_base_dir)
-
+        run = cli_func.load_run_file(path_dir=config.config_base_dir)
         from deepdriver.sdk.data_types.run import set_run, Run, get_run
         set_run(run)
 
@@ -152,18 +150,68 @@ def artifact(config, command, type, name, tag, path):
         cli_func.api_setting(config)
         cli_func.api_login(config)
 
-        run = cli_func.run_load(path_dir=config.config_base_dir)
-
+        run = cli_func.load_run_file(path_dir=config.config_base_dir)
         from deepdriver.sdk.data_types.run import set_run, Run, get_run
         set_run(run)
+
         arti = deepdriver.get_artifact(**{"type": type, "name": name, "tag": tag})
         arti.download(path)
 
 
+@click.command('hpo', short_help='Create or Run HPO(Hyper-parameter optimization)')
+@click.option('--exp_name', help='Experiment Name', required=False)
+@click.option('--team_name', help='Team Name', default="", required=False)
+@click.option('--tag', help='Tag of artifact', required=False)
+@click.option('--remote', help='Is Run HPO in remote', type=click.Choice(['True', 'False'], case_sensitive=False),
+              required=False)
+@click.option('--config', help='HPO Config File Path or Json String', required=False)
+@click.option('--artifact', help='Artifact Name', required=False)
+@click.option('--count', help='Count', type=click.INT, required=False)
+@click.argument('command', type=click.Choice(['create', 'run'], case_sensitive=False), required=True)
+@pass_config
+def hpo(ctx_config, exp_name, team_name, tag, remote, config, artifact, count, command):
+    if command == "create":
+        print("create")
+        cli_func.api_setting(ctx_config)
+        cli_func.api_login(ctx_config)
+
+        try:
+            config = json.loads(config)
+        except ValueError:
+            pass
+        params = {
+            "exp_name": exp_name,
+            "team_name": team_name,
+            "remote": remote,
+            "hpo_config": config,
+        }
+        deepdriver.create_hpo(**{k: v for k, v in params.items() if v is not None})
+
+
+    elif command == "run":
+        cli_func.api_setting(ctx_config)
+        cli_func.api_login(ctx_config)
+
+        try:
+            artifact = json.loads(artifact)
+        except ValueError:
+            pass
+
+        params = {
+            "exp_name": exp_name,
+            "team_name": team_name,
+            "remote": remote,
+            "artifact": artifact,
+            "count": count,
+        }
+        deepdriver.run_hpo(**{k: v for k, v in params.items() if v is not None})
+
+
 cli.add_command(setting)
 cli.add_command(login)
 cli.add_command(init)
 cli.add_command(artifact)
+cli.add_command(hpo)
 
 if __name__ == "__main__":
     cli()
