@@ -8,12 +8,13 @@ from deepdriver import logger
 from deepdriver.sdk.chart.chart import Chart, TYPE_CONFUSION_MATRIX, TYPE_ROC_CURVE, TYPE_HISTOGRAM, TYPE_BAR
 from deepdriver.sdk.data_types.image import Image
 from deepdriver.sdk.data_types.table import Table
+import numpy as np
 
 
 def visualize(obj: Union[Chart, Table, Image]) -> None:
     assert_that(obj).is_not_none()
 
-    def visualize_table(obj):
+    def visualize_table(obj: Table):
         # from IPython.core.display import display, HTML
         # display(HTML(obj.data.dataframe._repr_html_()))
 
@@ -28,19 +29,45 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         )
         fig.show()
 
-    def visualize_image(obj):
+    def visualize_image(obj: Image):
         # from IPython.core.display import display, HTML
         # display(HTML(obj.data.dataframe._repr_html_()))
 
         plotly_path = "plotly.express"
         plotly_module = importlib.import_module(plotly_path)
-        import numpy as np
+
         fig = plotly_module.imshow(
             np.array(obj.data)
         )
+        # show bounding boxes and  caption ( annotations )
+        if obj.boxes:
+            if 'box_data' not in obj.boxes.to_dict():
+                return
+
+            for box in obj.boxes.to_dict()['box_data']:
+                box: dict = box
+                if "position" in box:
+                    fig.add_shape(
+                        type='rect',
+                        x0=box["position"]["minX"], x1=box["position"]["maxX"], y0=box["position"]["minY"],
+                        y1=box["position"]["maxY"],
+                        xref='x', yref='y',
+                        line_color='blue'
+                    )
+
+                if "caption" in box:
+                    fig.add_annotation(
+                        x=box["position"]["minX"],
+                        xanchor='left',
+                        y=box["position"]["minY"] - 18,
+                        yanchor='top',
+                        text=box["caption"],
+                        showarrow=False,
+                        height=25, font_color='white', bgcolor='black', )
+
         fig.show()
 
-    def visualize_chart_common(obj):
+    def visualize_chart_common(obj: Chart):
         # line, scatter 차트
         plotly_path = "plotly.express"
         plotly_module = importlib.import_module(plotly_path)
@@ -54,7 +81,7 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         )
         fig.show()
 
-    def visualize_chart_bar(obj):
+    def visualize_chart_bar(obj: Chart):
         # bar 차트
         plotly_path = "plotly.express"
         plotly_module = importlib.import_module(plotly_path)
@@ -69,7 +96,7 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         )
         fig.show()
 
-    def visualize_chart_histogram(obj):
+    def visualize_chart_histogram(obj: Chart):
         # historgram
         plotly_path = "plotly.express"
         plotly_module = importlib.import_module(plotly_path)
@@ -93,7 +120,7 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
             )
             fig.show()
 
-    def visualize_confusion_matrix(obj):
+    def visualize_confusion_matrix(obj: Chart):
         # dataframe 에서 x, y, z 값 추출
         actual = obj.data.dataframe['Actual']
         predicted = obj.data.dataframe['Predicted']
@@ -140,7 +167,7 @@ def visualize(obj: Union[Chart, Table, Image]) -> None:
         fig = plotly_module.Figure(data=data, layout=layout)
         fig.show()
 
-    def visualize_roc_curve(obj):
+    def visualize_roc_curve(obj: Chart):
         """
            class  fpr    tpr
         0   cat  0.0  0.000
